@@ -1,7 +1,7 @@
 package Pod::Weaver::Plugin::PERLANCAR::SortSections;
 
-our $DATE = '2016-12-31'; # DATE
-our $VERSION = '0.05'; # VERSION
+our $DATE = '2017-02-14'; # DATE
+our $VERSION = '0.06'; # VERSION
 
 use 5.010001;
 use Moose;
@@ -63,12 +63,16 @@ sub finalize_document {
             'HISTORY',
             'HOMEPAGE',
             'SOURCE',
+            qr/^.+'S BUGS$/i, # in a forked module, i put the original module's BUGS in ORIGMODULE'S BUGS
             'BUGS',
             'SEE ALSO',
 
             # author & copyright
-            'AUTHOR',
+            qr/^.+'S AUTHORS?$/i, # in a forked module, i put the original module's AUTHOR in ORIGMODULE'S AUTHOR
+            qr/^AUTHORS?/,
+            qr/^.+'S COPYRIGHT( AND LICENSE)?$/i, # in a forked module, i put the original module's COPYRIGHT in ORIGMODULE'S COPYRIGHT
             'COPYRIGHT AND LICENSE',
+            'COPYRIGHT',
         ],
     );
 }
@@ -89,7 +93,7 @@ Pod::Weaver::Plugin::PERLANCAR::SortSections - Sort POD sections like PERLANCAR
 
 =head1 VERSION
 
-This document describes version 0.05 of Pod::Weaver::Plugin::PERLANCAR::SortSections (from Perl distribution Pod-Weaver-Plugin-PERLANCAR-SortSections), released on 2016-12-31.
+This document describes version 0.06 of Pod::Weaver::Plugin::PERLANCAR::SortSections (from Perl distribution Pod-Weaver-Plugin-PERLANCAR-SortSections), released on 2017-02-14.
 
 =head1 SYNOPSIS
 
@@ -127,7 +131,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by perlancar@cpan.org.
+This software is copyright (c) 2017, 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
